Page 164 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 164

Home

    warming.

    One of the disconcerting things about the theory of
    Global Warming was the lack of professional
    consultation upon the part of leaders of the Earth
    Summit. Dixie Lee Ray had this to say about the concern
    of leading world scientists:

    Global

    of

    was

    In contrast to the predictions of impending ecological
    doom from Strong, Bruntland, and other UN leaders of
    the Earth Summit, more than 250 of the world's leading
    scientists, including 27 Nobel laureates, released a
    statement on June 1, 1992, called the Heidelberg Appeal.
    It was directed to the heads of state that were attending

    am Ae 1 ~4ae oa

    the Rio Conference and appealed for the use of common
    sense and reliable science in making recommendations
    for action on environmental problems. As background,
    the scientists pointed out that it is neither reasonable nor
    prudent for major political decisions to be based on
    presumptions about issues in science, which, in the
    current state of knowledge, are still only hypotheses.
    They pointed out that in the more than two years of
    preparation for the Earth Summit, there was no
    significant involvement of scientists who specialize in the
    specific problem areas under consideration, nor were the
    competent scientists even informed.’

    Unfortunately, this appeal was neither acknowledged
    nor considered at the Earth Summit. All of the actions

    159

    U.N. Modern Tower of Babel

    government, was based upon the theory of global

    Warming

    Dixie Lee Ray went on to add this comment:

    taken there were without the benefit of competent